Update to latest Flutter candidate version (#9351)

diff --git a/flutter-candidate.txt b/flutter-candidate.txt
index 99dc991..bda69ff 100644
--- a/flutter-candidate.txt
+++ b/flutter-candidate.txt
@@ -1 +1 @@
-c2ea27002b9c4ab1aff1db6eb1960e4299aca369
+a9f310a4c91a523c42495a4e528dad76048c01a5
diff --git a/packages/devtools_shared/test/semantic_version_test.dart b/packages/devtools_shared/test/semantic_version_test.dart
index d5902b5..8e22b57 100644
--- a/packages/devtools_shared/test/semantic_version_test.dart
+++ b/packages/devtools_shared/test/semantic_version_test.dart
@@ -22,16 +22,18 @@
         SemanticVersion.parse('2.6.0-12.0.pre.443').toString(),
         equals('2.6.0-12.0'),
       );
-
       expect(
         SemanticVersion.parse('2.6.0-1.2.dev+build.metadata').toString(),
         equals('2.6.0-1.2'),
       );
-
       expect(
         SemanticVersion.parse('2.6.0+build.metadata').toString(),
         equals('2.6.0'),
       );
+      expect(
+        SemanticVersion.parse('3.33.0-1.0.pre-1156').toString(),
+        equals('3.33.0-1.0'),
+      );
     });
 
     test('downgrade', () {
diff --git a/packages/devtools_shared/lib/src/utils/semantic_version.dart b/packages/devtools_shared/lib/src/utils/semantic_version.dart
index 0430a10..98d9644 100644
--- a/packages/devtools_shared/lib/src/utils/semantic_version.dart
+++ b/packages/devtools_shared/lib/src/utils/semantic_version.dart
@@ -30,10 +30,14 @@
     // 2.15.0-233.0.dev (dev) (Mon Oct 18 14:06:26 2021 -0700) on "ios_x64"
     // 2.15.0-178.1.beta
     // 2.6.0-12.0.pre.443
+    // 2.6.0-12.0.pre-443
     //
-    // So split on the spaces to the version, and then on the dash char to
+    // First canonicalize the version string to convert any prerelease suffix
+    // with a "-" to a prerelease suffix with a ".".
+    final canonicalized = _canonicalizeVersion(versionString);
+    // Then split on the spaces to the version, and then on the dash char to
     // separate the main semantic version from the pre release version.
-    final splitOnSpaces = versionString.split(' ');
+    final splitOnSpaces = canonicalized.split(' ');
     final version = splitOnSpaces.first;
     final splitOnDash = version.split('-');
     assert(splitOnDash.length <= 2, 'version: $version');
@@ -115,6 +119,16 @@
 
   int? preReleaseMinor;
 
+  static final _nonStandardPreReleaseVersionRegex = RegExp(r'(\.pre)-(\d+)$');
+
+  /// Canonicalizes a [semanticVersion] with a prerelease version suffix to use
+  /// a "." instead of a "-".
+  ///
+  /// e.g. 2.6.0-12.0.pre-443 -> 2.6.0-12.0.pre.443
+  static String _canonicalizeVersion(String semanticVersion) =>
+      semanticVersion.replaceFirstMapped(_nonStandardPreReleaseVersionRegex,
+          (match) => '${match[1]}.${match[2]}');
+
   bool get isPreRelease => preReleaseMajor != null || preReleaseMinor != null;
 
   bool isSupported({required SemanticVersion minSupportedVersion}) =>